@@ -4,7 +4,7 @@
 
 import pandas as pd
 import hashlib
-from p_connector_dfg.Crypto.Cipher import AES
+from Crypto.Cipher import AES
 import numpy as np
 from pm4py.visualization.dfg import factory as dfg_vis_factory
 
